@@ -6,6 +6,7 @@ acquisition. Used with some ImageAnalysers to receive images and to react to sta
 acquisitions.
 """
 
+from ctypes import alignment
 import json
 import logging
 import re
@@ -26,10 +27,12 @@ SOCKET = "5556"
 class EventThread(QObject):
     """Thread that receives events from Micro-Manager and relays them to the main program. """
 
-    def __init__(self):
+    def __init__(self, alignment: bool = False):
         """Set up the bridge to Micro-Manager, ZMQ sockets and the main listener Thread."""
         super().__init__()
 
+        self.alignment = alignment
+
         self.bridge = Bridge(debug=False)
 
         # Make sockets that events circle through to always have a ready socket
@@ -64,7 +67,8 @@ class EventThread(QObject):
 
         # Set up the main listener Thread
         self.thread = QThread()
-        self.listener = EventListener(self.socket, self.event_sockets, self.bridge, self.thread)
+        self.listener = EventListener(self.socket, self.event_sockets, self.bridge, self.thread,
+                                      self.alignment)
         self.listener.moveToThread(self.thread)
         self.thread.started.connect(self.listener.start)
         self.listener.stop_thread_event.connect(self.stop)
@@ -99,8 +103,11 @@ class EventListener(QObject):
     mda_settings_event = Signal(MMSettings)
     settings_event = Signal(str, str, str)
     live_mode_event = Signal(bool)
+    xy_stage_position_changed_event = Signal(tuple)
+    stage_position_changed_event = Signal(float)
 
-    def __init__(self, socket, event_sockets, bridge: Bridge, thread: QThread):
+    def __init__(self, socket, event_sockets, bridge: Bridge, thread: QThread,
+                 alignment: bool = False):
         """Store passed arguments and starting time for frequency limitation of certain events."""
         super().__init__()
         self.loop_stop = False
@@ -179,6 +186,16 @@ class EventListener(QObject):
                     self.configuration_settings_event.emit(
                         evt.get_device(), evt.get_property(), evt.get_value()
                     )
+                elif "DefaultStagePositionChangedEvent" in eventString:
+                    if (
+                        self.blockZ > 0
+                        or time.perf_counter() - self.last_stage_position < 0.05
+                    ):
+                        print("BLOCKED ", self.blockZ)
+                    else:
+                        self.stage_position_changed_event.emit(evt.get_pos() * 100)
+                    self.last_stage_position = time.perf_counter()
+                    self.blockZ = False
                 elif "CustomMDAEvent" in eventString:
                     if time.perf_counter() - self.last_custom_mda > 0.2:
                         settings = evt.get_settings()
@@ -193,6 +210,10 @@ class EventListener(QObject):
                     self.settings_event.emit(
                         evt.get_device(), evt.get_property(), evt.get_value()
                     )
+                elif "XYStagePositionChangedEvent" in eventString:
+                    self.xy_stage_position_changed_event.emit(
+                        (evt.get_x_pos(), evt.get_y_pos())
+                    )
             except zmq.error.Again:
                 self.timeouts += 1
                 # print("Server timeout", self.timeouts)
